type LogLevelLiteral = "fatal" | "error" | "warn" | "log" | "info" | "success" | "debug" | "trace" | "silent" | "verbose";
type LogLevel = number;
type logType = "silent" | "fatal" | "error" | "warn" | "log" | "info" | "success" | "debug" | "trace" | "verbose" | "ready" | "start";
interface ConsolaLogObject {
    level?: LogLevel | LogLevelLiteral;
    tag?: string;
    type?: logType;
    message?: string;
    additional?: string | string[];
    args?: any[];
    date?: Date;
}
interface ConsolaReporterLogObject {
    level: LogLevel;
    type: logType;
    tag: string;
    args: any[];
    date: Date;
}
type ConsolaMock = (...args: any) => void;
type ConsolaMockFn = (type: logType, defaults: ConsolaLogObject) => ConsolaMock;
interface ConsolaReporterArgs {
    async: boolean;
    stdout: NodeJS.WritableStream;
    stderr: NodeJS.WritableStream;
}
interface ConsolaReporter {
    log: (logObj: ConsolaReporterLogObject, args: ConsolaReporterArgs) => void;
}
interface ConsolaOptions {
    reporters?: ConsolaReporter[];
    types?: Record<logType, ConsolaLogObject>;
    level?: LogLevel;
    defaults?: ConsolaLogObject;
    async?: boolean;
    stdout?: NodeJS.WritableStream;
    stderr?: NodeJS.WritableStream;
    mockFn?: ConsolaMockFn;
    throttle?: number;
    throttleMin?: number;
}

interface _ConsolaLoggers {
    fatal(message: ConsolaLogObject | any, ...args: any[]): void;
    error(message: ConsolaLogObject | any, ...args: any[]): void;
    warn(message: ConsolaLogObject | any, ...args: any[]): void;
    log(message: ConsolaLogObject | any, ...args: any[]): void;
    info(message: ConsolaLogObject | any, ...args: any[]): void;
    start(message: ConsolaLogObject | any, ...args: any[]): void;
    success(message: ConsolaLogObject | any, ...args: any[]): void;
    ready(message: ConsolaLogObject | any, ...args: any[]): void;
    debug(message: ConsolaLogObject | any, ...args: any[]): void;
    trace(message: ConsolaLogObject | any, ...args: any[]): void;
}
declare class Consola {
    _reporters: ConsolaReporter[];
    _types: Record<logType, ConsolaLogObject>;
    _level: LogLevel;
    _defaults: ConsolaLogObject;
    _async: boolean | undefined;
    _stdout: any;
    _stderr: any;
    _mockFn: ConsolaMockFn | undefined;
    _throttle: any;
    _throttleMin: any;
    _lastLogSerialized: any;
    _lastLog: any;
    _lastLogTime: any;
    _lastLogCount: any;
    _throttleTimeout: any;
    options: ConsolaOptions;
    constructor(options?: Partial<ConsolaOptions>);
    get level(): number;
    set level(level: number);
    get stdout(): any;
    get stderr(): any;
    create(options: ConsolaOptions): Consola;
    withDefaults(defaults: ConsolaLogObject): Consola;
    withTag(tag: string): Consola;
    addReporter(reporter: ConsolaReporter): this;
    removeReporter(reporter: ConsolaReporter): this | ConsolaReporter[];
    setReporters(reporters: ConsolaReporter[]): this;
    wrapAll(): void;
    restoreAll(): void;
    wrapConsole(): void;
    restoreConsole(): void;
    wrapStd(): void;
    _wrapStream(stream: NodeJS.WritableStream, type: string): void;
    restoreStd(): void;
    _restoreStream(stream: NodeJS.WritableStream): void;
    pauseLogs(): void;
    resumeLogs(): void;
    mockTypes(mockFn?: (type: string, currentType: any) => any): void;
    _wrapLogFn(defaults: ConsolaLogObject, isRaw?: boolean): (...args: any[]) => false | Promise<boolean> | undefined;
    _logFn(defaults: ConsolaLogObject, args: any[], isRaw?: boolean): false | Promise<boolean> | undefined;
    _log(logObj: ConsolaReporterLogObject): void;
    _logAsync(logObj: ConsolaReporterLogObject): Promise<void[]>;
}
declare function createConsola(options: Partial<ConsolaOptions>): Consola & _ConsolaLoggers;

declare const Types: Record<string, ConsolaLogObject>;

declare const LogLevels: {
    Fatal: number;
    Error: number;
    Warn: number;
    Log: number;
    Info: number;
    Success: number;
    Debug: number;
    Trace: number;
    Silent: number;
    Verbose: number;
};

declare function isLogObj(arg: any): boolean;

declare function assignGlobalConsola(newConsola: any): any;

export { Consola as C, LogLevels as L, Types as T, assignGlobalConsola as a, createConsola as c, isLogObj as i };
